import { Provider, Widget } from '@tinystacks/ops-model';
import { OutputLogEvent } from '@aws-sdk/client-cloudwatch-logs';
export type AwsKeys = {
    AwsAccessKeyId: string;
    AwsSecretAccessKey: string;
    AwsSessionToken?: string;
};
export type LocalAwsProfile = {
    profileName: string;
};
export type AwsAssumedRole = {
    roleArn: string;
    sessionName: string;
    region: string;
    primaryCredentials: AwsCredentials;
    duration?: number;
};
export type AwsCredentials = AwsAssumedRole | AwsKeys | LocalAwsProfile;
export type AwsCredentialsProvider = Provider & {
    credentials: AwsCredentials;
    accountId?: string;
    region?: string;
    cliEnv?: {
        [key: string]: string;
    };
};
export declare enum TimeUnit {
    ns = "ns",
    ms = "ms",
    s = "s",
    m = "m",
    hr = "h",
    d = "d",
    w = "w",
    mo = "mo",
    yr = "yr"
}
export type AbsoluteTimeRange = {
    startTime: number;
    endTime: number;
};
export type RelativeTime = {
    time: number;
    unit: TimeUnit;
};
export type TimeRange = AbsoluteTimeRange | RelativeTime;
export type AwsCloudWatchLogs = Widget & {
    region: string;
    logGroupName: string;
    logStreamName?: string;
    timeRange: TimeRange;
    showTimeRangeSelector?: boolean;
    events?: OutputLogEvent[];
};
export type PipelineAction = {
    name: string;
    status: string;
    lastStatusChange?: Date;
    token?: string;
    category: string;
    provider: string;
    runOrder: number;
};
export type StageAction = PipelineAction & {
    stageName: string;
};
export type PipelineStage = {
    name: string;
    status: string;
    actions: PipelineAction[];
};
export type Pipeline = {
    name: string;
    arn: string;
    stages: PipelineStage[];
};
export type AwsCodePipeline = Widget & {
    pipelineName: string;
    region: string;
    pipeline?: Pipeline;
};
export type AwsEcsDeployments = Widget & {
    region: string;
    clusterName: string;
    serviceName: string;
};
export type AwsEcsInfo = Widget & {
    region: string;
    clusterName: string;
    serviceName: string;
};
export type AwsIamJson = Widget & {
    region: string;
    roleArn?: string;
    policyArn?: string;
};
export type AwsJsonTree = Widget & {
    region: string;
    cloudControlType: string;
    resourceModel?: string;
    paths?: string[];
};
